@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "GameView.hpp"
 
-#include <SDL.h>                           // for SDL_BUTTON_LEFT, SDL_SetCu...
+#include <SDL.h>                           // for SDL_BUTTON_LEFT, SDL_BUTTO...
 #include <SDL_image.h>                     // for IMG_Load_RW
 #include <assert.h>                        // for assert
 #include <physfs.h>                        // for PHYSFS_exists
@@ -80,7 +80,7 @@ const float GameView::defaultZoom = 1.0;    // fastest drawing
 GameView* gameViewPtr = 0;
 
 GameView* getGameView() {
-  if(!gameViewPtr) throw std::runtime_error("gameViewPtr is not initialized");
+  assert(gameViewPtr);
   return gameViewPtr;
 }
 
